@@ -1,5 +1,6 @@
 {-# LANGUAGE CPP #-}
 {-# OPTIONS_GHC -fno-warn-warnings-deprecations #-}
+{-# OPTIONS_HADDOCK hide #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Network
@@ -25,7 +26,7 @@
 #define IPV6_SOCKET_SUPPORT 1
 #endif
 
-module Network
+module Network {-# DEPRECATED "The high level Network interface is no longer supported. Please use Network.Socket." #-}
     (
     -- * Basic data types
       Socket
