@@ -1,4 +1,6 @@
 {-# LANGUAGE BangPatterns #-}
+{-# LANGUAGE OverloadedStrings #-}
+
 module Network.Socket.ByteString.Lazy.Windows
     (
     -- * Send data to a socket
@@ -7,13 +9,14 @@ module Network.Socket.ByteString.Lazy.Windows
     ) where
 
 import Control.Applicative ((<$>))
-import Control.Monad (unless)
+import Control.Monad (when)
 import qualified Data.ByteString as S
 import qualified Data.ByteString.Lazy as L
 import Data.Int (Int64)
 
 import Network.Socket (Socket(..))
 import qualified Network.Socket.ByteString as Socket
+import Network.Socket.ByteString.Internal (waitWhen0)
 
 -- -----------------------------------------------------------------------------
 -- Sending
@@ -30,7 +33,8 @@ send sock s = do
 sendAll :: Socket        -- ^ Connected socket
         -> L.ByteString  -- ^ Data to send
         -> IO ()
+sendAll _    "" = return ()
 sendAll sock bs = do
   sent <- send sock bs
-  let bs' = L.drop sent bs
-  unless (L.null bs') $ sendAll sock bs'
+  waitWhen0 (fromIntegral sent) sock
+  when (sent >= 0) $ sendAll sock $ L.drop sent bs
