@@ -1,29 +1,22 @@
 /* -----------------------------------------------------------------------------
  *
- * Definitions for package `net' which are visible in Haskell land.
+ * Definitions for package `network' which are visible in Haskell land.
  *
  * ---------------------------------------------------------------------------*/
 
 #ifndef HSNET_H
 #define HSNET_H
 
-#include "HsNetworkConfig.h"
+#include "HsNetDef.h"
 
 #ifdef NEED_WINVER
 # define WINVER 0x0501
 #endif
 
-/* ultra-evil... */
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-
 #ifndef INLINE
 # if defined(_MSC_VER)
 #  define INLINE extern __inline
-# elif defined(__GNUC__)
+# elif defined(__GNUC_GNU_INLINE__)
 #  define INLINE extern inline
 # else
 #  define INLINE inline
@@ -36,18 +29,14 @@
 # undef IPV6_SOCKET_SUPPORT
 #endif
 
-#if defined(HAVE_WINSOCK2_H) && !defined(__CYGWIN__)
+#if defined(HAVE_WINSOCK2_H)
 #include <winsock2.h>
 # ifdef HAVE_WS2TCPIP_H
 #  include <ws2tcpip.h>
 // fix for MingW not defining IPV6_V6ONLY
 #  define IPV6_V6ONLY 27
 # endif
-# ifdef HAVE_WSPIAPI_H
-#  include <wspiapi.h>
-# endif
 
-extern void  shutdownWinSock();
 extern int   initWinSock ();
 extern const char* getWSErrorDescr(int err);
 extern void* newAcceptParams(int sock,
@@ -79,7 +68,9 @@ extern int   acceptDoProc(void* param);
 #ifdef HAVE_SYS_SOCKET_H
 # include <sys/socket.h>
 #endif
-#ifdef HAVE_NETINET_TCP_H
+#ifdef HAVE_LINUX_TCP_H
+# include <linux/tcp.h>
+#elif HAVE_NETINET_TCP_H
 # include <netinet/tcp.h>
 #endif
 #ifdef HAVE_NETINET_IN_H
@@ -94,6 +85,13 @@ extern int   acceptDoProc(void* param);
 #ifdef HAVE_NETDB_H
 #include <netdb.h>
 #endif
+#ifdef HAVE_LINUX_CAN_H
+# include <linux/can.h>
+# define CAN_SOCKET_SUPPORT 1
+#endif
+#ifdef HAVE_NET_IF
+# include <net/if.h>
+#endif
 
 #ifdef HAVE_BSD_SENDFILE
 #include <sys/uio.h>
@@ -110,10 +108,10 @@ sendFd(int sock, int outfd);
 extern int
 recvFd(int sock);
 
-#endif /* HAVE_WINSOCK2_H && !__CYGWIN */
+#endif /* HAVE_WINSOCK2_H */
 
 INLINE char *
-my_inet_ntoa(
+hsnet_inet_ntoa(
 #if defined(HAVE_WINSOCK2_H)
              u_long addr
 #elif defined(HAVE_IN_ADDR_T)
@@ -124,7 +122,7 @@ my_inet_ntoa(
              unsigned long addr
 #endif
 	    )
-{ 
+{
     struct in_addr a;
     a.s_addr = addr;
     return inet_ntoa(a);
@@ -133,7 +131,7 @@ my_inet_ntoa(
 #ifdef HAVE_GETADDRINFO
 INLINE int
 hsnet_getnameinfo(const struct sockaddr* a,socklen_t b, char* c,
-# if defined(HAVE_WINSOCK2_H) && !defined(__CYGWIN__)
+# if defined(HAVE_WINSOCK2_H)
                   DWORD d, char* e, DWORD f, int g)
 # else
                   socklen_t d, char* e, socklen_t f, int g)
@@ -156,24 +154,12 @@ hsnet_freeaddrinfo(struct addrinfo *ai)
 }
 #endif
 
-#if defined(HAVE_WINSOCK2_H) && !defined(cygwin32_HOST_OS)
-# define WITH_WINSOCK  1
-#endif
-
-#if !defined(mingw32_HOST_OS) && !defined(_WIN32)
-# define DOMAIN_SOCKET_SUPPORT 1
-#endif
-
-#if !defined(CALLCONV)
-# if defined(WITH_WINSOCK)
-#  define CALLCONV stdcall
-# else
-#  define CALLCONV ccall
-# endif
-#endif
-
 #if !defined(IOV_MAX)
 # define IOV_MAX 1024
 #endif
 
+#if !defined(SOCK_NONBLOCK) // Missing define in Bionic libc (Android)
+# define SOCK_NONBLOCK O_NONBLOCK
+#endif
+
 #endif /* HSNET_H */
